@@ -1,7 +1,7 @@
 /* gok-button.h
 *
-* Copyright 2001,2002 Sun Microsystems, Inc.,
-* Copyright 2001,2002 University Of Toronto
+* Copyright 2001-2009 Sun Microsystems, Inc.,
+* Copyright 2001-2009 University Of Toronto
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -23,46 +23,44 @@
 #define __GOKBUTTON_H__
 
 #include <gtk/gtk.h>
-#include <gdk/gdk.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+#include "gok-key.h"
 
-#define GOK_TYPE_BUTTON                  (gok_button_get_type ())
-#define GOK_BUTTON(obj)                  (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOK_TYPE_BUTTON, GokButton))
-#define GOK_BUTTON_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, GOK_TYPE_BUTTON, GokButtonClass)
-#define GOK_IS_BUTTON(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, GOK_TYPE_BUTTON)
-#define GOK_IS_BUTTON_CLASS(klass)       G_TYPE_CHECK_CLASS_TYPE (klass, GOK_TYPE_BUTTON)
+G_BEGIN_DECLS
 
-typedef struct _GokButton       GokButton;
-typedef struct _GokButtonClass  GokButtonClass;
+#define GOK_TYPE_BUTTON        (gok_button_get_type ())
+#define GOK_BUTTON(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), GOK_TYPE_BUTTON, GokButton))
+#define GOK_BUTTON_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST (k, GOK_TYPE_BUTTON, GokButtonClass)
+#define GOK_IS_BUTTON(o)       (G_TYPE_CHECK_INSTANCE_TYPE (o, GOK_TYPE_BUTTON))
+#define GOK_IS_BUTTON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE (k, GOK_TYPE_BUTTON))
+
+typedef struct _GokButton      GokButton;
+typedef struct _GokButtonClass GokButtonClass;
 
 struct _GokButton
 {
-	GtkToggleButton button;
+	GtkToggleButton parent;
+
 	GtkWidget* pBox;
 	GtkWidget* pLabel;
         GtkWidget* pImage;
+        gchar     *indicator_type;
 };
 
 struct _GokButtonClass
 {
-  GtkToggleButtonClass parent_class;
+	GtkToggleButtonClass parent;
 };
 
-GtkType    gok_button_get_type (void) G_GNUC_CONST;
-GtkWidget* gok_button_new_with_label (const gchar *pText);
-GtkWidget* gok_button_new_with_image (GtkWidget *image);
+GType      gok_button_get_type (void) G_GNUC_CONST;
+GtkWidget* gok_button_new_with_label (const gchar *pText, GokImagePlacementPolicy align);
+GtkWidget* gok_button_new_with_image (GtkWidget *image, GokImagePlacementPolicy align);
 void gok_button_set_image (GokButton *button, GtkImage *image);
 void gok_button_set_label (GokButton *button, GtkLabel *label);
 gint gok_button_enter_notify   (GtkWidget *widget, GdkEventCrossing   *event);
 gint gok_button_leave_notify   (GtkWidget *widget, GdkEventCrossing   *event);
 void gok_button_state_changed   (GtkWidget *widget, GtkStateType state, gpointer user_data);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
-
+G_END_DECLS
 
 #endif /* __GOKBUTTON_H__ */
