@@ -355,32 +355,30 @@ void on_button_help (GtkButton* pButton, gpointer user_data)
 			break;
 			
 		case 1:
-			help_link_id = "gok-keyboards";
+			help_link_id = "gok-prefs-keyboards";
 			break;
 			
 		case 2:
-			help_link_id = "gok-prefs-Actions";
+			help_link_id = "gok-prefs-actions";
 			break;
 			
 		case 3:
-			help_link_id = "gok-prefs-Feedback";
+			help_link_id = "gok-prefs-feedback";
 			break;
 
 		case 4:
-			help_link_id = "gok-prefs-Access-Methods";
+			help_link_id = "gok-prefs-accessmethods";
 			break;
 			
 		case 5:
-			help_link_id = "gok-prefs-Prediction";
+			help_link_id = "gok-prefs-prediction";
 			break;
 			
 		default:
 			break;
 	}
-	if (help_link_id)
-	{
-		gnome_help_display_desktop (NULL, "gok", "gok.xml", help_link_id, NULL);
-	}
+
+	gok_main_display_help ("gok", help_link_id);
 }
 
 /**
